@@ -122,16 +122,16 @@ class path(_base):
 
     # Make the / operator work even when true division is enabled.
     __truediv__ = __div__
-    
+
     def __rdiv__(self, rel):
         return self.__class__(os.path.join(rel, self))
-    
+
     __rtruediv__ = __rdiv__
-    
-    def getcwd(cls):
+
+    @classmethod
+    def cwd(cls):
         """ Return the current working directory as a path object. """
         return cls(_getcwd())
-    getcwd = classmethod(getcwd)
 
 
     # --- Operations on path strings.
@@ -364,7 +364,7 @@ class path(_base):
         whose names match the given pattern.  For example,
         ``d.files('*.pyc')``.
         """
-        
+
         return [p for p in self.listdir(pattern) if p.isfile()]
 
     def walk(self, pattern=None, errors='strict'):
@@ -537,7 +537,7 @@ class path(_base):
             return f.read()
         finally:
             f.close()
-    
+
     def write_bytes(self, bytes, append=False):
         """ Open this file and write the given bytes to it.
 
@@ -554,8 +554,8 @@ class path(_base):
                 f.write(bytes)
             finally:
                 f.close()
-        
-        dry("write_bytes %s '%.20s...' append=%r" % (self, bytes, append),
+
+        dry("write_bytes %s '%r...' append=%r" % (self, bytes[:20], append),
             _write_bytes, bytes, append)
 
     def text(self, encoding=None, errors='strict'):
@@ -777,9 +777,9 @@ class path(_base):
 
     def read_md5(self, hex=False):
         """ Calculate the md5 hash for this file.
-        
+
         hex - Return the digest as hex string.
-        
+
         This reads through the entire file.
         """
         f = self.open('rb')
@@ -800,31 +800,27 @@ class path(_base):
     # --- Methods for querying the filesystem.
 
     exists = os.path.exists
-    isdir = os.path.isdir
     isfile = os.path.isfile
     islink = os.path.islink
     ismount = os.path.ismount
 
+    def isdir(self):
+        # isdir is a built-in on windows, need to wrap
+        return os.path.isdir(self)
+    isdir.__doc__ = os.path.isdir.__doc__
+
     if hasattr(os.path, 'samefile'):
         samefile = os.path.samefile
 
-    
-    atime = property(
-        os.path.getatime, None, None,
-        """ Last access time of the file. """)
-    
-    mtime = property(
-        os.path.getmtime, None, None,
-        """ Last-modified time of the file. """)
 
-    if hasattr(os.path, 'getctime'):
-        ctime = property(
-            os.path.getctime, None, None,
-            """ Creation time of the file. """)
+    atime = os.path.getatime
+    mtime = os.path.getmtime
+    ctime = os.path.getctime
 
-    size = property(
-        os.path.getsize, None, None,
-        """ Size of the file, in bytes. """)
+    def newer(self, other):
+        return self.mtime > other.mtime
+
+    size = os.path.getsize
 
     if hasattr(os, 'access'):
         def access(self, mode):
@@ -842,7 +838,7 @@ class path(_base):
         """ Like path.stat(), but do not follow symbolic links. """
         return os.lstat(self)
 
-    def _get_owner(self):
+    def owner(self):
         r""" Return the name of the owner of this file or directory.
 
         This follows symbolic links.
@@ -864,10 +860,6 @@ class path(_base):
             st = self.stat()
             return pwd.getpwuid(st.st_uid).pw_name
 
-    owner = property(
-        _get_owner, None, None,
-        _get_owner.__doc__)
-    del _get_owner
 
     if hasattr(os, 'statvfs'):
         def statvfs(self):
@@ -880,7 +872,7 @@ class path(_base):
 
 
     # --- Modifying operations on files and directories
-    
+
     @dry_guard
     def utime(self, times):
         """ Set the access and modified times of this file. """
@@ -918,6 +910,14 @@ class path(_base):
     def makedirs(self, mode=0777):
         os.makedirs(self, mode)
 
+    @dry_guard
+    def ensure_dir(self, mode=0777):
+        """
+        Make sure the directory exists, create if necessary.
+        """
+        if not self.exists() or not self.isdir():
+            os.makedirs(self, mode)
+
     @dry_guard
     def rmdir(self):
         os.rmdir(self)
@@ -992,9 +992,9 @@ class path(_base):
     if hasattr(shutil, 'move'):
         move = dry_guard(shutil.move)
     rmtree = dry_guard(shutil.rmtree)
-    
+
     # --- Convenience for scriptine
-    
+
     @dry_guard
     def install(self, to, chmod=0644):
         """
@@ -1012,12 +1012,19 @@ class path(_base):
     if hasattr(os, 'startfile'):
         def startfile(self):
             os.startfile(self)
-    
+
     # --- contextmanagers
     try:
         from contextlib import contextmanager
         @contextmanager
         def as_working_dir(self):
+            """
+            temporarily change into this directory
+
+            >>> with path('/').as_working_dir():
+            ...     assert path.cwd() == '/'
+            >>> assert path.cwd() != '/'
+            """
             current_dir = path(os.curdir).abspath()
             os.chdir(self)
             try:
