@@ -20,8 +20,8 @@ def parse_and_run_function(function, args=None, command_name=None,
     params_doc = parse_rst_params(func_doc)
     
     usage = 'usage: %prog '
-    if command_name is not None:
-        usage += command_name + ' '
+    if command_name:
+        usage += command_name.replace('_', '-') + ' '
     usage += '[options] ' + ' '.join(required_args)
     
     if func_doc:
@@ -164,7 +164,7 @@ def inspect_args(function):
         optional_args.reverse()
     return args, optional_args
 
-def run(namespace=None, args=None, command_suffix='_command',
+def autocmds(namespace=None, args=None, command_suffix='_command',
         add_dry_run_option=True, add_verbosity_option=True):
     """
     Parse and run commands.
@@ -195,6 +195,13 @@ def run(namespace=None, args=None, command_suffix='_command',
         add_dry_run_option=add_dry_run_option,
         add_verbosity_option=add_verbosity_option)
 
+run = autocmds
+
+def cmd(function, args=None):
+    if args is None:
+        args = sys.argv
+    parse_and_run_function(function, args, '',)
+
 def print_help(namespace, command_suffix):
     group_commands = defaultdict(list)
     for func_name, func in namespace.iteritems():
